# karp-lex-core

- **karp-lex-core** [![PyPI version](https://badge.fury.io/py/karp-lex-core.svg)](https://badge.fury.io/py/karp-lex-core)

The core for karp-lex

Contains commands, entry_dto and unique_id for `karp.lex` in `karp.backend`.

# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## Latest Changes

## 0.4.0
### Added
* Added Generic Commands. PR [#224](https://github.com/spraakbanken/karp-backend/pull/224) by [@kod-kristoff](https://github.com/kod-kristoff).
* Added cmdtype tags. PR [#223](https://github.com/spraakbanken/karp-backend/pull/223) by [@kod-kristoff](https://github.com/kod-kristoff).

## 0.3.2

* Repo move to https://github/spraakbanken/karp-backend from https://github/spraakbanken/karp-lex-core